// generated by script
#include "bind_consts.h"


void bind_consts(py::module &m) {
    py::module consts = m.def_submodule("consts", "API Consts");

    consts.attr("THOST_TERT_RESTART") = 0;
    consts.attr("THOST_TERT_RESUME") = 1;
    consts.attr("THOST_TERT_QUICK") = 2;
    consts.attr("THOST_TERT_NONE") = 3;
    consts.attr("THOST_FTDC_EXP_Normal") = "0";
    consts.attr("THOST_FTDC_EXP_GenOrderByTrade") = "1";
    consts.attr("THOST_FTDC_ICT_EID") = "0";
    consts.attr("THOST_FTDC_ICT_IDCard") = "1";
    consts.attr("THOST_FTDC_ICT_OfficerIDCard") = "2";
    consts.attr("THOST_FTDC_ICT_PoliceIDCard") = "3";
    consts.attr("THOST_FTDC_ICT_SoldierIDCard") = "4";
    consts.attr("THOST_FTDC_ICT_HouseholdRegister") = "5";
    consts.attr("THOST_FTDC_ICT_Passport") = "6";
    consts.attr("THOST_FTDC_ICT_TaiwanCompatriotIDCard") = "7";
    consts.attr("THOST_FTDC_ICT_HomeComingCard") = "8";
    consts.attr("THOST_FTDC_ICT_LicenseNo") = "9";
    consts.attr("THOST_FTDC_ICT_TaxNo") = "A";
    consts.attr("THOST_FTDC_ICT_HMMainlandTravelPermit") = "B";
    consts.attr("THOST_FTDC_ICT_TwMainlandTravelPermit") = "C";
    consts.attr("THOST_FTDC_ICT_DrivingLicense") = "D";
    consts.attr("THOST_FTDC_ICT_SocialID") = "F";
    consts.attr("THOST_FTDC_ICT_LocalID") = "G";
    consts.attr("THOST_FTDC_ICT_BusinessRegistration") = "H";
    consts.attr("THOST_FTDC_ICT_HKMCIDCard") = "I";
    consts.attr("THOST_FTDC_ICT_AccountsPermits") = "J";
    consts.attr("THOST_FTDC_ICT_FrgPrmtRdCard") = "K";
    consts.attr("THOST_FTDC_ICT_CptMngPrdLetter") = "L";
    consts.attr("THOST_FTDC_ICT_UniformSocialCreditCode") = "N";
    consts.attr("THOST_FTDC_ICT_CorporationCertNo") = "O";
    consts.attr("THOST_FTDC_ICT_OtherCard") = "x";
    consts.attr("THOST_FTDC_IR_All") = "1";
    consts.attr("THOST_FTDC_IR_Group") = "2";
    consts.attr("THOST_FTDC_IR_Single") = "3";
    consts.attr("THOST_FTDC_DR_All") = "1";
    consts.attr("THOST_FTDC_DR_Group") = "2";
    consts.attr("THOST_FTDC_DR_Single") = "3";
    consts.attr("THOST_FTDC_DS_Asynchronous") = "1";
    consts.attr("THOST_FTDC_DS_Synchronizing") = "2";
    consts.attr("THOST_FTDC_DS_Synchronized") = "3";
    consts.attr("THOST_FTDC_BDS_Synchronized") = "1";
    consts.attr("THOST_FTDC_BDS_Synchronizing") = "2";
    consts.attr("THOST_FTDC_ECS_NoConnection") = "1";
    consts.attr("THOST_FTDC_ECS_QryInstrumentSent") = "2";
    consts.attr("THOST_FTDC_ECS_GotInformation") = "9";
    consts.attr("THOST_FTDC_TCS_NotConnected") = "1";
    consts.attr("THOST_FTDC_TCS_Connected") = "2";
    consts.attr("THOST_FTDC_TCS_QryInstrumentSent") = "3";
    consts.attr("THOST_FTDC_TCS_SubPrivateFlow") = "4";
    consts.attr("THOST_FTDC_FC_DataAsync") = "1";
    consts.attr("THOST_FTDC_FC_ForceUserLogout") = "2";
    consts.attr("THOST_FTDC_FC_UserPasswordUpdate") = "3";
    consts.attr("THOST_FTDC_FC_BrokerPasswordUpdate") = "4";
    consts.attr("THOST_FTDC_FC_InvestorPasswordUpdate") = "5";
    consts.attr("THOST_FTDC_FC_OrderInsert") = "6";
    consts.attr("THOST_FTDC_FC_OrderAction") = "7";
    consts.attr("THOST_FTDC_FC_SyncSystemData") = "8";
    consts.attr("THOST_FTDC_FC_SyncBrokerData") = "9";
    consts.attr("THOST_FTDC_FC_BachSyncBrokerData") = "A";
    consts.attr("THOST_FTDC_FC_SuperQuery") = "B";
    consts.attr("THOST_FTDC_FC_ParkedOrderInsert") = "C";
    consts.attr("THOST_FTDC_FC_ParkedOrderAction") = "D";
    consts.attr("THOST_FTDC_FC_SyncOTP") = "E";
    consts.attr("THOST_FTDC_FC_DeleteOrder") = "F";
    consts.attr("THOST_FTDC_BFC_ForceUserLogout") = "1";
    consts.attr("THOST_FTDC_BFC_UserPasswordUpdate") = "2";
    consts.attr("THOST_FTDC_BFC_SyncBrokerData") = "3";
    consts.attr("THOST_FTDC_BFC_BachSyncBrokerData") = "4";
    consts.attr("THOST_FTDC_BFC_OrderInsert") = "5";
    consts.attr("THOST_FTDC_BFC_OrderAction") = "6";
    consts.attr("THOST_FTDC_BFC_AllQuery") = "7";
    consts.attr("THOST_FTDC_BFC_log") = "a";
    consts.attr("THOST_FTDC_BFC_BaseQry") = "b";
    consts.attr("THOST_FTDC_BFC_TradeQry") = "c";
    consts.attr("THOST_FTDC_BFC_Trade") = "d";
    consts.attr("THOST_FTDC_BFC_Virement") = "e";
    consts.attr("THOST_FTDC_BFC_Risk") = "f";
    consts.attr("THOST_FTDC_BFC_Session") = "g";
    consts.attr("THOST_FTDC_BFC_RiskNoticeCtl") = "h";
    consts.attr("THOST_FTDC_BFC_RiskNotice") = "i";
    consts.attr("THOST_FTDC_BFC_BrokerDeposit") = "j";
    consts.attr("THOST_FTDC_BFC_QueryFund") = "k";
    consts.attr("THOST_FTDC_BFC_QueryOrder") = "l";
    consts.attr("THOST_FTDC_BFC_QueryTrade") = "m";
    consts.attr("THOST_FTDC_BFC_QueryPosition") = "n";
    consts.attr("THOST_FTDC_BFC_QueryMarketData") = "o";
    consts.attr("THOST_FTDC_BFC_QueryUserEvent") = "p";
    consts.attr("THOST_FTDC_BFC_QueryRiskNotify") = "q";
    consts.attr("THOST_FTDC_BFC_QueryFundChange") = "r";
    consts.attr("THOST_FTDC_BFC_QueryInvestor") = "s";
    consts.attr("THOST_FTDC_BFC_QueryTradingCode") = "t";
    consts.attr("THOST_FTDC_BFC_ForceClose") = "u";
    consts.attr("THOST_FTDC_BFC_PressTest") = "v";
    consts.attr("THOST_FTDC_BFC_RemainCalc") = "w";
    consts.attr("THOST_FTDC_BFC_NetPositionInd") = "x";
    consts.attr("THOST_FTDC_BFC_RiskPredict") = "y";
    consts.attr("THOST_FTDC_BFC_DataExport") = "z";
    consts.attr("THOST_FTDC_BFC_RiskTargetSetup") = "A";
    consts.attr("THOST_FTDC_BFC_MarketDataWarn") = "B";
    consts.attr("THOST_FTDC_BFC_QryBizNotice") = "C";
    consts.attr("THOST_FTDC_BFC_CfgBizNotice") = "D";
    consts.attr("THOST_FTDC_BFC_SyncOTP") = "E";
    consts.attr("THOST_FTDC_BFC_SendBizNotice") = "F";
    consts.attr("THOST_FTDC_BFC_CfgRiskLevelStd") = "G";
    consts.attr("THOST_FTDC_BFC_TbCommand") = "H";
    consts.attr("THOST_FTDC_BFC_DeleteOrder") = "J";
    consts.attr("THOST_FTDC_BFC_ParkedOrderInsert") = "K";
    consts.attr("THOST_FTDC_BFC_ParkedOrderAction") = "L";
    consts.attr("THOST_FTDC_BFC_ExecOrderNoCheck") = "M";
    consts.attr("THOST_FTDC_BFC_Designate") = "N";
    consts.attr("THOST_FTDC_BFC_StockDisposal") = "O";
    consts.attr("THOST_FTDC_BFC_BrokerDepositWarn") = "Q";
    consts.attr("THOST_FTDC_BFC_CoverWarn") = "S";
    consts.attr("THOST_FTDC_BFC_PreExecOrder") = "T";
    consts.attr("THOST_FTDC_BFC_ExecOrderRisk") = "P";
    consts.attr("THOST_FTDC_BFC_PosiLimitWarn") = "U";
    consts.attr("THOST_FTDC_BFC_QryPosiLimit") = "V";
    consts.attr("THOST_FTDC_BFC_FBSign") = "W";
    consts.attr("THOST_FTDC_BFC_FBAccount") = "X";
    consts.attr("THOST_FTDC_OAS_Submitted") = "a";
    consts.attr("THOST_FTDC_OAS_Accepted") = "b";
    consts.attr("THOST_FTDC_OAS_Rejected") = "c";
    consts.attr("THOST_FTDC_OST_AllTraded") = "0";
    consts.attr("THOST_FTDC_OST_PartTradedQueueing") = "1";
    consts.attr("THOST_FTDC_OST_PartTradedNotQueueing") = "2";
    consts.attr("THOST_FTDC_OST_NoTradeQueueing") = "3";
    consts.attr("THOST_FTDC_OST_NoTradeNotQueueing") = "4";
    consts.attr("THOST_FTDC_OST_Canceled") = "5";
    consts.attr("THOST_FTDC_OST_Unknown") = "a";
    consts.attr("THOST_FTDC_OST_NotTouched") = "b";
    consts.attr("THOST_FTDC_OST_Touched") = "c";
    consts.attr("THOST_FTDC_OSS_InsertSubmitted") = "0";
    consts.attr("THOST_FTDC_OSS_CancelSubmitted") = "1";
    consts.attr("THOST_FTDC_OSS_ModifySubmitted") = "2";
    consts.attr("THOST_FTDC_OSS_Accepted") = "3";
    consts.attr("THOST_FTDC_OSS_InsertRejected") = "4";
    consts.attr("THOST_FTDC_OSS_CancelRejected") = "5";
    consts.attr("THOST_FTDC_OSS_ModifyRejected") = "6";
    consts.attr("THOST_FTDC_PSD_Today") = "1";
    consts.attr("THOST_FTDC_PSD_History") = "2";
    consts.attr("THOST_FTDC_PDT_UseHistory") = "1";
    consts.attr("THOST_FTDC_PDT_NoUseHistory") = "2";
    consts.attr("THOST_FTDC_ER_Broker") = "1";
    consts.attr("THOST_FTDC_ER_Host") = "2";
    consts.attr("THOST_FTDC_ER_Maker") = "3";
    consts.attr("THOST_FTDC_PC_Futures") = "1";
    consts.attr("THOST_FTDC_PC_Options") = "2";
    consts.attr("THOST_FTDC_PC_Combination") = "3";
    consts.attr("THOST_FTDC_PC_Spot") = "4";
    consts.attr("THOST_FTDC_PC_EFP") = "5";
    consts.attr("THOST_FTDC_PC_SpotOption") = "6";
    consts.attr("THOST_FTDC_PC_TAS") = "7";
    consts.attr("THOST_FTDC_PC_MI") = "I";
    consts.attr("THOST_FTDC_APC_FutureSingle") = "1";
    consts.attr("THOST_FTDC_APC_OptionSingle") = "2";
    consts.attr("THOST_FTDC_APC_Futures") = "3";
    consts.attr("THOST_FTDC_APC_Options") = "4";
    consts.attr("THOST_FTDC_APC_TradingComb") = "5";
    consts.attr("THOST_FTDC_APC_UnTradingComb") = "6";
    consts.attr("THOST_FTDC_APC_AllTrading") = "7";
    consts.attr("THOST_FTDC_APC_All") = "8";
    consts.attr("THOST_FTDC_IP_NotStart") = "0";
    consts.attr("THOST_FTDC_IP_Started") = "1";
    consts.attr("THOST_FTDC_IP_Pause") = "2";
    consts.attr("THOST_FTDC_IP_Expired") = "3";
    consts.attr("THOST_FTDC_D_Buy") = "0";
    consts.attr("THOST_FTDC_D_Sell") = "1";
    consts.attr("THOST_FTDC_PT_Net") = "1";
    consts.attr("THOST_FTDC_PT_Gross") = "2";
    consts.attr("THOST_FTDC_PD_Net") = "1";
    consts.attr("THOST_FTDC_PD_Long") = "2";
    consts.attr("THOST_FTDC_PD_Short") = "3";
    consts.attr("THOST_FTDC_SS_NonActive") = "1";
    consts.attr("THOST_FTDC_SS_Startup") = "2";
    consts.attr("THOST_FTDC_SS_Operating") = "3";
    consts.attr("THOST_FTDC_SS_Settlement") = "4";
    consts.attr("THOST_FTDC_SS_SettlementFinished") = "5";
    consts.attr("THOST_FTDC_RA_Trade") = "0";
    consts.attr("THOST_FTDC_RA_Settlement") = "1";
    consts.attr("THOST_FTDC_HF_Speculation") = "1";
    consts.attr("THOST_FTDC_HF_Arbitrage") = "2";
    consts.attr("THOST_FTDC_HF_Hedge") = "3";
    consts.attr("THOST_FTDC_HF_MarketMaker") = "5";
    consts.attr("THOST_FTDC_HF_SpecHedge") = "6";
    consts.attr("THOST_FTDC_HF_HedgeSpec") = "7";
    consts.attr("THOST_FTDC_BHF_Speculation") = "1";
    consts.attr("THOST_FTDC_BHF_Arbitrage") = "2";
    consts.attr("THOST_FTDC_BHF_Hedge") = "3";
    consts.attr("THOST_FTDC_CIDT_Speculation") = "1";
    consts.attr("THOST_FTDC_CIDT_Arbitrage") = "2";
    consts.attr("THOST_FTDC_CIDT_Hedge") = "3";
    consts.attr("THOST_FTDC_CIDT_MarketMaker") = "5";
    consts.attr("THOST_FTDC_OPT_AnyPrice") = "1";
    consts.attr("THOST_FTDC_OPT_LimitPrice") = "2";
    consts.attr("THOST_FTDC_OPT_BestPrice") = "3";
    consts.attr("THOST_FTDC_OPT_LastPrice") = "4";
    consts.attr("THOST_FTDC_OPT_LastPricePlusOneTicks") = "5";
    consts.attr("THOST_FTDC_OPT_LastPricePlusTwoTicks") = "6";
    consts.attr("THOST_FTDC_OPT_LastPricePlusThreeTicks") = "7";
    consts.attr("THOST_FTDC_OPT_AskPrice1") = "8";
    consts.attr("THOST_FTDC_OPT_AskPrice1PlusOneTicks") = "9";
    consts.attr("THOST_FTDC_OPT_AskPrice1PlusTwoTicks") = "A";
    consts.attr("THOST_FTDC_OPT_AskPrice1PlusThreeTicks") = "B";
    consts.attr("THOST_FTDC_OPT_BidPrice1") = "C";
    consts.attr("THOST_FTDC_OPT_BidPrice1PlusOneTicks") = "D";
    consts.attr("THOST_FTDC_OPT_BidPrice1PlusTwoTicks") = "E";
    consts.attr("THOST_FTDC_OPT_BidPrice1PlusThreeTicks") = "F";
    consts.attr("THOST_FTDC_OPT_FiveLevelPrice") = "G";
    consts.attr("THOST_FTDC_OF_Open") = "0";
    consts.attr("THOST_FTDC_OF_Close") = "1";
    consts.attr("THOST_FTDC_OF_ForceClose") = "2";
    consts.attr("THOST_FTDC_OF_CloseToday") = "3";
    consts.attr("THOST_FTDC_OF_CloseYesterday") = "4";
    consts.attr("THOST_FTDC_OF_ForceOff") = "5";
    consts.attr("THOST_FTDC_OF_LocalForceClose") = "6";
    consts.attr("THOST_FTDC_FCC_NotForceClose") = "0";
    consts.attr("THOST_FTDC_FCC_LackDeposit") = "1";
    consts.attr("THOST_FTDC_FCC_ClientOverPositionLimit") = "2";
    consts.attr("THOST_FTDC_FCC_MemberOverPositionLimit") = "3";
    consts.attr("THOST_FTDC_FCC_NotMultiple") = "4";
    consts.attr("THOST_FTDC_FCC_Violation") = "5";
    consts.attr("THOST_FTDC_FCC_Other") = "6";
    consts.attr("THOST_FTDC_FCC_PersonDeliv") = "7";
    consts.attr("THOST_FTDC_ORDT_Normal") = "0";
    consts.attr("THOST_FTDC_ORDT_DeriveFromQuote") = "1";
    consts.attr("THOST_FTDC_ORDT_DeriveFromCombination") = "2";
    consts.attr("THOST_FTDC_ORDT_Combination") = "3";
    consts.attr("THOST_FTDC_ORDT_ConditionalOrder") = "4";
    consts.attr("THOST_FTDC_ORDT_Swap") = "5";
    consts.attr("THOST_FTDC_ORDT_DeriveFromBlockTrade") = "6";
    consts.attr("THOST_FTDC_ORDT_DeriveFromEFPTrade") = "7";
    consts.attr("THOST_FTDC_TC_IOC") = "1";
    consts.attr("THOST_FTDC_TC_GFS") = "2";
    consts.attr("THOST_FTDC_TC_GFD") = "3";
    consts.attr("THOST_FTDC_TC_GTD") = "4";
    consts.attr("THOST_FTDC_TC_GTC") = "5";
    consts.attr("THOST_FTDC_TC_GFA") = "6";
    consts.attr("THOST_FTDC_VC_AV") = "1";
    consts.attr("THOST_FTDC_VC_MV") = "2";
    consts.attr("THOST_FTDC_VC_CV") = "3";
    consts.attr("THOST_FTDC_CC_Immediately") = "1";
    consts.attr("THOST_FTDC_CC_Touch") = "2";
    consts.attr("THOST_FTDC_CC_TouchProfit") = "3";
    consts.attr("THOST_FTDC_CC_ParkedOrder") = "4";
    consts.attr("THOST_FTDC_CC_LastPriceGreaterThanStopPrice") = "5";
    consts.attr("THOST_FTDC_CC_LastPriceGreaterEqualStopPrice") = "6";
    consts.attr("THOST_FTDC_CC_LastPriceLesserThanStopPrice") = "7";
    consts.attr("THOST_FTDC_CC_LastPriceLesserEqualStopPrice") = "8";
    consts.attr("THOST_FTDC_CC_AskPriceGreaterThanStopPrice") = "9";
    consts.attr("THOST_FTDC_CC_AskPriceGreaterEqualStopPrice") = "A";
    consts.attr("THOST_FTDC_CC_AskPriceLesserThanStopPrice") = "B";
    consts.attr("THOST_FTDC_CC_AskPriceLesserEqualStopPrice") = "C";
    consts.attr("THOST_FTDC_CC_BidPriceGreaterThanStopPrice") = "D";
    consts.attr("THOST_FTDC_CC_BidPriceGreaterEqualStopPrice") = "E";
    consts.attr("THOST_FTDC_CC_BidPriceLesserThanStopPrice") = "F";
    consts.attr("THOST_FTDC_CC_BidPriceLesserEqualStopPrice") = "H";
    consts.attr("THOST_FTDC_AF_Delete") = "0";
    consts.attr("THOST_FTDC_AF_Modify") = "3";
    consts.attr("THOST_FTDC_TR_Allow") = "0";
    consts.attr("THOST_FTDC_TR_CloseOnly") = "1";
    consts.attr("THOST_FTDC_TR_Forbidden") = "2";
    consts.attr("THOST_FTDC_OSRC_Participant") = "0";
    consts.attr("THOST_FTDC_OSRC_Administrator") = "1";
    consts.attr("THOST_FTDC_TRDT_SplitCombination") = "#";
    consts.attr("THOST_FTDC_TRDT_Common") = "0";
    consts.attr("THOST_FTDC_TRDT_OptionsExecution") = "1";
    consts.attr("THOST_FTDC_TRDT_OTC") = "2";
    consts.attr("THOST_FTDC_TRDT_EFPDerived") = "3";
    consts.attr("THOST_FTDC_TRDT_CombinationDerived") = "4";
    consts.attr("THOST_FTDC_TRDT_BlockTrade") = "5";
    consts.attr("THOST_FTDC_SPOST_Common") = "#";
    consts.attr("THOST_FTDC_SPOST_Tas") = "0";
    consts.attr("THOST_FTDC_PSRC_LastPrice") = "0";
    consts.attr("THOST_FTDC_PSRC_Buy") = "1";
    consts.attr("THOST_FTDC_PSRC_Sell") = "2";
    consts.attr("THOST_FTDC_PSRC_OTC") = "3";
    consts.attr("THOST_FTDC_IS_BeforeTrading") = "0";
    consts.attr("THOST_FTDC_IS_NoTrading") = "1";
    consts.attr("THOST_FTDC_IS_Continous") = "2";
    consts.attr("THOST_FTDC_IS_AuctionOrdering") = "3";
    consts.attr("THOST_FTDC_IS_AuctionBalance") = "4";
    consts.attr("THOST_FTDC_IS_AuctionMatch") = "5";
    consts.attr("THOST_FTDC_IS_Closed") = "6";
    consts.attr("THOST_FTDC_IER_Automatic") = "1";
    consts.attr("THOST_FTDC_IER_Manual") = "2";
    consts.attr("THOST_FTDC_IER_Fuse") = "3";
    consts.attr("THOST_FTDC_BS_NoUpload") = "1";
    consts.attr("THOST_FTDC_BS_Uploaded") = "2";
    consts.attr("THOST_FTDC_BS_Failed") = "3";
    consts.attr("THOST_FTDC_RS_All") = "1";
    consts.attr("THOST_FTDC_RS_ByProduct") = "2";
    consts.attr("THOST_FTDC_RP_ByVolume") = "1";
    consts.attr("THOST_FTDC_RP_ByFeeOnHand") = "2";
    consts.attr("THOST_FTDC_RL_Level1") = "1";
    consts.attr("THOST_FTDC_RL_Level2") = "2";
    consts.attr("THOST_FTDC_RL_Level3") = "3";
    consts.attr("THOST_FTDC_RL_Level4") = "4";
    consts.attr("THOST_FTDC_RL_Level5") = "5";
    consts.attr("THOST_FTDC_RL_Level6") = "6";
    consts.attr("THOST_FTDC_RL_Level7") = "7";
    consts.attr("THOST_FTDC_RL_Level8") = "8";
    consts.attr("THOST_FTDC_RL_Level9") = "9";
    consts.attr("THOST_FTDC_RSD_ByPeriod") = "1";
    consts.attr("THOST_FTDC_RSD_ByStandard") = "2";
    consts.attr("THOST_FTDC_MT_Out") = "0";
    consts.attr("THOST_FTDC_MT_In") = "1";
    consts.attr("THOST_FTDC_ISPI_MortgageRatio") = "4";
    consts.attr("THOST_FTDC_ISPI_MarginWay") = "5";
    consts.attr("THOST_FTDC_ISPI_BillDeposit") = "9";
    consts.attr("THOST_FTDC_ESPI_MortgageRatio") = "1";
    consts.attr("THOST_FTDC_ESPI_OtherFundItem") = "2";
    consts.attr("THOST_FTDC_ESPI_OtherFundImport") = "3";
    consts.attr("THOST_FTDC_ESPI_CFFEXMinPrepa") = "6";
    consts.attr("THOST_FTDC_ESPI_CZCESettlementType") = "7";
    consts.attr("THOST_FTDC_ESPI_ExchDelivFeeMode") = "9";
    consts.attr("THOST_FTDC_ESPI_DelivFeeMode") = "0";
    consts.attr("THOST_FTDC_ESPI_CZCEComMarginType") = "A";
    consts.attr("THOST_FTDC_ESPI_DceComMarginType") = "B";
    consts.attr("THOST_FTDC_ESPI_OptOutDisCountRate") = "a";
    consts.attr("THOST_FTDC_ESPI_OptMiniGuarantee") = "b";
    consts.attr("THOST_FTDC_SPI_InvestorIDMinLength") = "1";
    consts.attr("THOST_FTDC_SPI_AccountIDMinLength") = "2";
    consts.attr("THOST_FTDC_SPI_UserRightLogon") = "3";
    consts.attr("THOST_FTDC_SPI_SettlementBillTrade") = "4";
    consts.attr("THOST_FTDC_SPI_TradingCode") = "5";
    consts.attr("THOST_FTDC_SPI_CheckFund") = "6";
    consts.attr("THOST_FTDC_SPI_CommModelRight") = "7";
    consts.attr("THOST_FTDC_SPI_MarginModelRight") = "9";
    consts.attr("THOST_FTDC_SPI_IsStandardActive") = "8";
    consts.attr("THOST_FTDC_SPI_UploadSettlementFile") = "U";
    consts.attr("THOST_FTDC_SPI_DownloadCSRCFile") = "D";
    consts.attr("THOST_FTDC_SPI_SettlementBillFile") = "S";
    consts.attr("THOST_FTDC_SPI_CSRCOthersFile") = "C";
    consts.attr("THOST_FTDC_SPI_InvestorPhoto") = "P";
    consts.attr("THOST_FTDC_SPI_CSRCData") = "R";
    consts.attr("THOST_FTDC_SPI_InvestorPwdModel") = "I";
    consts.attr("THOST_FTDC_SPI_CFFEXInvestorSettleFile") = "F";
    consts.attr("THOST_FTDC_SPI_InvestorIDType") = "a";
    consts.attr("THOST_FTDC_SPI_FreezeMaxReMain") = "r";
    consts.attr("THOST_FTDC_SPI_IsSync") = "A";
    consts.attr("THOST_FTDC_SPI_RelieveOpenLimit") = "O";
    consts.attr("THOST_FTDC_SPI_IsStandardFreeze") = "X";
    consts.attr("THOST_FTDC_SPI_CZCENormalProductHedge") = "B";
    consts.attr("THOST_FTDC_TPID_EncryptionStandard") = "E";
    consts.attr("THOST_FTDC_TPID_RiskMode") = "R";
    consts.attr("THOST_FTDC_TPID_RiskModeGlobal") = "G";
    consts.attr("THOST_FTDC_TPID_modeEncode") = "P";
    consts.attr("THOST_FTDC_TPID_tickMode") = "T";
    consts.attr("THOST_FTDC_TPID_SingleUserSessionMaxNum") = "S";
    consts.attr("THOST_FTDC_TPID_LoginFailMaxNum") = "L";
    consts.attr("THOST_FTDC_TPID_IsAuthForce") = "A";
    consts.attr("THOST_FTDC_TPID_IsPosiFreeze") = "F";
    consts.attr("THOST_FTDC_TPID_IsPosiLimit") = "M";
    consts.attr("THOST_FTDC_TPID_ForQuoteTimeInterval") = "Q";
    consts.attr("THOST_FTDC_TPID_IsFuturePosiLimit") = "B";
    consts.attr("THOST_FTDC_TPID_IsFutureOrderFreq") = "C";
    consts.attr("THOST_FTDC_TPID_IsExecOrderProfit") = "H";
    consts.attr("THOST_FTDC_TPID_IsCheckBankAcc") = "I";
    consts.attr("THOST_FTDC_TPID_PasswordDeadLine") = "J";
    consts.attr("THOST_FTDC_TPID_IsStrongPassword") = "K";
    consts.attr("THOST_FTDC_TPID_BalanceMorgage") = "a";
    consts.attr("THOST_FTDC_TPID_MinPwdLen") = "O";
    consts.attr("THOST_FTDC_TPID_LoginFailMaxNumForIP") = "U";
    consts.attr("THOST_FTDC_TPID_PasswordPeriod") = "V";
    consts.attr("THOST_FTDC_FI_SettlementFund") = "F";
    consts.attr("THOST_FTDC_FI_Trade") = "T";
    consts.attr("THOST_FTDC_FI_InvestorPosition") = "P";
    consts.attr("THOST_FTDC_FI_SubEntryFund") = "O";
    consts.attr("THOST_FTDC_FI_CZCECombinationPos") = "C";
    consts.attr("THOST_FTDC_FI_CSRCData") = "R";
    consts.attr("THOST_FTDC_FI_CZCEClose") = "L";
    consts.attr("THOST_FTDC_FI_CZCENoClose") = "N";
    consts.attr("THOST_FTDC_FI_PositionDtl") = "D";
    consts.attr("THOST_FTDC_FI_OptionStrike") = "S";
    consts.attr("THOST_FTDC_FI_SettlementPriceComparison") = "M";
    consts.attr("THOST_FTDC_FI_NonTradePosChange") = "B";
    consts.attr("THOST_FTDC_FUT_Settlement") = "0";
    consts.attr("THOST_FTDC_FUT_Check") = "1";
    consts.attr("THOST_FTDC_FFT_Txt") = "0";
    consts.attr("THOST_FTDC_FFT_Zip") = "1";
    consts.attr("THOST_FTDC_FFT_DBF") = "2";
    consts.attr("THOST_FTDC_FUS_SucceedUpload") = "1";
    consts.attr("THOST_FTDC_FUS_FailedUpload") = "2";
    consts.attr("THOST_FTDC_FUS_SucceedLoad") = "3";
    consts.attr("THOST_FTDC_FUS_PartSucceedLoad") = "4";
    consts.attr("THOST_FTDC_FUS_FailedLoad") = "5";
    consts.attr("THOST_FTDC_TD_Out") = "0";
    consts.attr("THOST_FTDC_TD_In") = "1";
    consts.attr("THOST_FTDC_SC_NoSpecialRule") = "0";
    consts.attr("THOST_FTDC_SC_NoSpringFestival") = "1";
    consts.attr("THOST_FTDC_IPT_LastSettlement") = "1";
    consts.attr("THOST_FTDC_IPT_LaseClose") = "2";
    consts.attr("THOST_FTDC_PLP_Active") = "1";
    consts.attr("THOST_FTDC_PLP_NonActive") = "2";
    consts.attr("THOST_FTDC_PLP_Canceled") = "3";
    consts.attr("THOST_FTDC_DM_CashDeliv") = "1";
    consts.attr("THOST_FTDC_DM_CommodityDeliv") = "2";
    consts.attr("THOST_FTDC_FIOT_FundIO") = "1";
    consts.attr("THOST_FTDC_FIOT_Transfer") = "2";
    consts.attr("THOST_FTDC_FIOT_SwapCurrency") = "3";
    consts.attr("THOST_FTDC_FT_Deposite") = "1";
    consts.attr("THOST_FTDC_FT_ItemFund") = "2";
    consts.attr("THOST_FTDC_FT_Company") = "3";
    consts.attr("THOST_FTDC_FT_InnerTransfer") = "4";
    consts.attr("THOST_FTDC_FD_In") = "1";
    consts.attr("THOST_FTDC_FD_Out") = "2";
    consts.attr("THOST_FTDC_FS_Record") = "1";
    consts.attr("THOST_FTDC_FS_Check") = "2";
    consts.attr("THOST_FTDC_FS_Charge") = "3";
    consts.attr("THOST_FTDC_PS_None") = "1";
    consts.attr("THOST_FTDC_PS_Publishing") = "2";
    consts.attr("THOST_FTDC_PS_Published") = "3";
    consts.attr("THOST_FTDC_ES_NonActive") = "1";
    consts.attr("THOST_FTDC_ES_Startup") = "2";
    consts.attr("THOST_FTDC_ES_Initialize") = "3";
    consts.attr("THOST_FTDC_ES_Initialized") = "4";
    consts.attr("THOST_FTDC_ES_Close") = "5";
    consts.attr("THOST_FTDC_ES_Closed") = "6";
    consts.attr("THOST_FTDC_ES_Settlement") = "7";
    consts.attr("THOST_FTDC_STS_Initialize") = "0";
    consts.attr("THOST_FTDC_STS_Settlementing") = "1";
    consts.attr("THOST_FTDC_STS_Settlemented") = "2";
    consts.attr("THOST_FTDC_STS_Finished") = "3";
    consts.attr("THOST_FTDC_CT_Person") = "0";
    consts.attr("THOST_FTDC_CT_Company") = "1";
    consts.attr("THOST_FTDC_CT_Fund") = "2";
    consts.attr("THOST_FTDC_CT_SpecialOrgan") = "3";
    consts.attr("THOST_FTDC_CT_Asset") = "4";
    consts.attr("THOST_FTDC_BT_Trade") = "0";
    consts.attr("THOST_FTDC_BT_TradeSettle") = "1";
    consts.attr("THOST_FTDC_FAS_Low") = "1";
    consts.attr("THOST_FTDC_FAS_Normal") = "2";
    consts.attr("THOST_FTDC_FAS_Focus") = "3";
    consts.attr("THOST_FTDC_FAS_Risk") = "4";
    consts.attr("THOST_FTDC_FAS_ByTrade") = "1";
    consts.attr("THOST_FTDC_FAS_ByDeliv") = "2";
    consts.attr("THOST_FTDC_FAS_None") = "3";
    consts.attr("THOST_FTDC_FAS_FixFee") = "4";
    consts.attr("THOST_FTDC_PWDT_Trade") = "1";
    consts.attr("THOST_FTDC_PWDT_Account") = "2";
    consts.attr("THOST_FTDC_AG_All") = "1";
    consts.attr("THOST_FTDC_AG_OnlyLost") = "2";
    consts.attr("THOST_FTDC_AG_OnlyGain") = "3";
    consts.attr("THOST_FTDC_AG_None") = "4";
    consts.attr("THOST_FTDC_ICP_Include") = "0";
    consts.attr("THOST_FTDC_ICP_NotInclude") = "2";
    consts.attr("THOST_FTDC_AWT_Enable") = "0";
    consts.attr("THOST_FTDC_AWT_Disable") = "2";
    consts.attr("THOST_FTDC_AWT_NoHoldEnable") = "3";
    consts.attr("THOST_FTDC_FPWD_UnCheck") = "0";
    consts.attr("THOST_FTDC_FPWD_Check") = "1";
    consts.attr("THOST_FTDC_TT_BankToFuture") = "0";
    consts.attr("THOST_FTDC_TT_FutureToBank") = "1";
    consts.attr("THOST_FTDC_TVF_Invalid") = "0";
    consts.attr("THOST_FTDC_TVF_Valid") = "1";
    consts.attr("THOST_FTDC_TVF_Reverse") = "2";
    consts.attr("THOST_FTDC_RN_CD") = "0";
    consts.attr("THOST_FTDC_RN_ZT") = "1";
    consts.attr("THOST_FTDC_RN_QT") = "2";
    consts.attr("THOST_FTDC_SEX_None") = "0";
    consts.attr("THOST_FTDC_SEX_Man") = "1";
    consts.attr("THOST_FTDC_SEX_Woman") = "2";
    consts.attr("THOST_FTDC_UT_Investor") = "0";
    consts.attr("THOST_FTDC_UT_Operator") = "1";
    consts.attr("THOST_FTDC_UT_SuperUser") = "2";
    consts.attr("THOST_FTDC_RATETYPE_MarginRate") = "2";
    consts.attr("THOST_FTDC_NOTETYPE_TradeSettleBill") = "1";
    consts.attr("THOST_FTDC_NOTETYPE_TradeSettleMonth") = "2";
    consts.attr("THOST_FTDC_NOTETYPE_CallMarginNotes") = "3";
    consts.attr("THOST_FTDC_NOTETYPE_ForceCloseNotes") = "4";
    consts.attr("THOST_FTDC_NOTETYPE_TradeNotes") = "5";
    consts.attr("THOST_FTDC_NOTETYPE_DelivNotes") = "6";
    consts.attr("THOST_FTDC_SBS_Day") = "1";
    consts.attr("THOST_FTDC_SBS_Volume") = "2";
    consts.attr("THOST_FTDC_ST_Day") = "0";
    consts.attr("THOST_FTDC_ST_Month") = "1";
    consts.attr("THOST_FTDC_URT_Logon") = "1";
    consts.attr("THOST_FTDC_URT_Transfer") = "2";
    consts.attr("THOST_FTDC_URT_EMail") = "3";
    consts.attr("THOST_FTDC_URT_Fax") = "4";
    consts.attr("THOST_FTDC_URT_ConditionOrder") = "5";
    consts.attr("THOST_FTDC_MPT_PreSettlementPrice") = "1";
    consts.attr("THOST_FTDC_MPT_SettlementPrice") = "2";
    consts.attr("THOST_FTDC_MPT_AveragePrice") = "3";
    consts.attr("THOST_FTDC_MPT_OpenPrice") = "4";
    consts.attr("THOST_FTDC_BGS_None") = "0";
    consts.attr("THOST_FTDC_BGS_NoGenerated") = "1";
    consts.attr("THOST_FTDC_BGS_Generated") = "2";
    consts.attr("THOST_FTDC_AT_HandlePositionAlgo") = "1";
    consts.attr("THOST_FTDC_AT_FindMarginRateAlgo") = "2";
    consts.attr("THOST_FTDC_HPA_Base") = "1";
    consts.attr("THOST_FTDC_HPA_DCE") = "2";
    consts.attr("THOST_FTDC_HPA_CZCE") = "3";
    consts.attr("THOST_FTDC_FMRA_Base") = "1";
    consts.attr("THOST_FTDC_FMRA_DCE") = "2";
    consts.attr("THOST_FTDC_FMRA_CZCE") = "3";
    consts.attr("THOST_FTDC_HTAA_Base") = "1";
    consts.attr("THOST_FTDC_HTAA_DCE") = "2";
    consts.attr("THOST_FTDC_HTAA_CZCE") = "3";
    consts.attr("THOST_FTDC_PST_Order") = "1";
    consts.attr("THOST_FTDC_PST_Open") = "2";
    consts.attr("THOST_FTDC_PST_Fund") = "3";
    consts.attr("THOST_FTDC_PST_Settlement") = "4";
    consts.attr("THOST_FTDC_PST_Company") = "5";
    consts.attr("THOST_FTDC_PST_Corporation") = "6";
    consts.attr("THOST_FTDC_PST_LinkMan") = "7";
    consts.attr("THOST_FTDC_PST_Ledger") = "8";
    consts.attr("THOST_FTDC_PST_Trustee") = "9";
    consts.attr("THOST_FTDC_PST_TrusteeCorporation") = "A";
    consts.attr("THOST_FTDC_PST_TrusteeOpen") = "B";
    consts.attr("THOST_FTDC_PST_TrusteeContact") = "C";
    consts.attr("THOST_FTDC_PST_ForeignerRefer") = "D";
    consts.attr("THOST_FTDC_PST_CorporationRefer") = "E";
    consts.attr("THOST_FTDC_QIR_All") = "1";
    consts.attr("THOST_FTDC_QIR_Group") = "2";
    consts.attr("THOST_FTDC_QIR_Single") = "3";
    consts.attr("THOST_FTDC_IRS_Normal") = "1";
    consts.attr("THOST_FTDC_IRS_Warn") = "2";
    consts.attr("THOST_FTDC_IRS_Call") = "3";
    consts.attr("THOST_FTDC_IRS_Force") = "4";
    consts.attr("THOST_FTDC_IRS_Exception") = "5";
    consts.attr("THOST_FTDC_UET_Login") = "1";
    consts.attr("THOST_FTDC_UET_Logout") = "2";
    consts.attr("THOST_FTDC_UET_Trading") = "3";
    consts.attr("THOST_FTDC_UET_TradingError") = "4";
    consts.attr("THOST_FTDC_UET_UpdatePassword") = "5";
    consts.attr("THOST_FTDC_UET_Authenticate") = "6";
    consts.attr("THOST_FTDC_UET_SubmitSysInfo") = "7";
    consts.attr("THOST_FTDC_UET_Transfer") = "8";
    consts.attr("THOST_FTDC_UET_Other") = "9";
    consts.attr("THOST_FTDC_ICS_Close") = "0";
    consts.attr("THOST_FTDC_ICS_CloseToday") = "1";
    consts.attr("THOST_FTDC_SM_Non") = "0";
    consts.attr("THOST_FTDC_SM_Instrument") = "1";
    consts.attr("THOST_FTDC_SM_Product") = "2";
    consts.attr("THOST_FTDC_SM_Investor") = "3";
    consts.attr("THOST_FTDC_PAOS_NotSend") = "1";
    consts.attr("THOST_FTDC_PAOS_Send") = "2";
    consts.attr("THOST_FTDC_PAOS_Deleted") = "3";
    consts.attr("THOST_FTDC_VDS_Dealing") = "1";
    consts.attr("THOST_FTDC_VDS_DeaclSucceed") = "2";
    consts.attr("THOST_FTDC_ORGS_Standard") = "0";
    consts.attr("THOST_FTDC_ORGS_ESunny") = "1";
    consts.attr("THOST_FTDC_ORGS_KingStarV6") = "2";
    consts.attr("THOST_FTDC_VTS_NaturalDeal") = "0";
    consts.attr("THOST_FTDC_VTS_SucceedEnd") = "1";
    consts.attr("THOST_FTDC_VTS_FailedEND") = "2";
    consts.attr("THOST_FTDC_VTS_Exception") = "3";
    consts.attr("THOST_FTDC_VTS_ManualDeal") = "4";
    consts.attr("THOST_FTDC_VTS_MesException") = "5";
    consts.attr("THOST_FTDC_VTS_SysException") = "6";
    consts.attr("THOST_FTDC_VBAT_BankBook") = "1";
    consts.attr("THOST_FTDC_VBAT_BankCard") = "2";
    consts.attr("THOST_FTDC_VBAT_CreditCard") = "3";
    consts.attr("THOST_FTDC_VMS_Natural") = "0";
    consts.attr("THOST_FTDC_VMS_Canceled") = "9";
    consts.attr("THOST_FTDC_VAA_NoAvailAbility") = "0";
    consts.attr("THOST_FTDC_VAA_AvailAbility") = "1";
    consts.attr("THOST_FTDC_VAA_Repeal") = "2";
    consts.attr("THOST_FTDC_VTC_BankBankToFuture") = "102001";
    consts.attr("THOST_FTDC_VTC_BankFutureToBank") = "102002";
    consts.attr("THOST_FTDC_VTC_FutureBankToFuture") = "202001";
    consts.attr("THOST_FTDC_VTC_FutureFutureToBank") = "202002";
    consts.attr("THOST_FTDC_GEN_Program") = "0";
    consts.attr("THOST_FTDC_GEN_HandWork") = "1";
    consts.attr("THOST_FTDC_CFMMCKK_REQUEST") = "R";
    consts.attr("THOST_FTDC_CFMMCKK_AUTO") = "A";
    consts.attr("THOST_FTDC_CFMMCKK_MANUAL") = "M";
    consts.attr("THOST_FTDC_CFT_IDCard") = "0";
    consts.attr("THOST_FTDC_CFT_Passport") = "1";
    consts.attr("THOST_FTDC_CFT_OfficerIDCard") = "2";
    consts.attr("THOST_FTDC_CFT_SoldierIDCard") = "3";
    consts.attr("THOST_FTDC_CFT_HomeComingCard") = "4";
    consts.attr("THOST_FTDC_CFT_HouseholdRegister") = "5";
    consts.attr("THOST_FTDC_CFT_LicenseNo") = "6";
    consts.attr("THOST_FTDC_CFT_InstitutionCodeCard") = "7";
    consts.attr("THOST_FTDC_CFT_TempLicenseNo") = "8";
    consts.attr("THOST_FTDC_CFT_NoEnterpriseLicenseNo") = "9";
    consts.attr("THOST_FTDC_CFT_OtherCard") = "x";
    consts.attr("THOST_FTDC_CFT_SuperDepAgree") = "a";
    consts.attr("THOST_FTDC_FBC_Others") = "0";
    consts.attr("THOST_FTDC_FBC_TransferDetails") = "1";
    consts.attr("THOST_FTDC_FBC_CustAccStatus") = "2";
    consts.attr("THOST_FTDC_FBC_AccountTradeDetails") = "3";
    consts.attr("THOST_FTDC_FBC_FutureAccountChangeInfoDetails") = "4";
    consts.attr("THOST_FTDC_FBC_CustMoneyDetail") = "5";
    consts.attr("THOST_FTDC_FBC_CustCancelAccountInfo") = "6";
    consts.attr("THOST_FTDC_FBC_CustMoneyResult") = "7";
    consts.attr("THOST_FTDC_FBC_OthersExceptionResult") = "8";
    consts.attr("THOST_FTDC_FBC_CustInterestNetMoneyDetails") = "9";
    consts.attr("THOST_FTDC_FBC_CustMoneySendAndReceiveDetails") = "a";
    consts.attr("THOST_FTDC_FBC_CorporationMoneyTotal") = "b";
    consts.attr("THOST_FTDC_FBC_MainbodyMoneyTotal") = "c";
    consts.attr("THOST_FTDC_FBC_MainPartMonitorData") = "d";
    consts.attr("THOST_FTDC_FBC_PreparationMoney") = "e";
    consts.attr("THOST_FTDC_FBC_BankMoneyMonitorData") = "f";
    consts.attr("THOST_FTDC_CEC_Exchange") = "1";
    consts.attr("THOST_FTDC_CEC_Cash") = "2";
    consts.attr("THOST_FTDC_YNI_Yes") = "0";
    consts.attr("THOST_FTDC_YNI_No") = "1";
    consts.attr("THOST_FTDC_BLT_CurrentMoney") = "0";
    consts.attr("THOST_FTDC_BLT_UsableMoney") = "1";
    consts.attr("THOST_FTDC_BLT_FetchableMoney") = "2";
    consts.attr("THOST_FTDC_BLT_FreezeMoney") = "3";
    consts.attr("THOST_FTDC_GD_Unknown") = "0";
    consts.attr("THOST_FTDC_GD_Male") = "1";
    consts.attr("THOST_FTDC_GD_Female") = "2";
    consts.attr("THOST_FTDC_FPF_BEN") = "0";
    consts.attr("THOST_FTDC_FPF_OUR") = "1";
    consts.attr("THOST_FTDC_FPF_SHA") = "2";
    consts.attr("THOST_FTDC_PWKT_ExchangeKey") = "0";
    consts.attr("THOST_FTDC_PWKT_PassWordKey") = "1";
    consts.attr("THOST_FTDC_PWKT_MACKey") = "2";
    consts.attr("THOST_FTDC_PWKT_MessageKey") = "3";
    consts.attr("THOST_FTDC_PWT_Query") = "0";
    consts.attr("THOST_FTDC_PWT_Fetch") = "1";
    consts.attr("THOST_FTDC_PWT_Transfer") = "2";
    consts.attr("THOST_FTDC_PWT_Trade") = "3";
    consts.attr("THOST_FTDC_EM_NoEncry") = "0";
    consts.attr("THOST_FTDC_EM_DES") = "1";
    consts.attr("THOST_FTDC_EM_3DES") = "2";
    consts.attr("THOST_FTDC_BRF_BankNotNeedRepeal") = "0";
    consts.attr("THOST_FTDC_BRF_BankWaitingRepeal") = "1";
    consts.attr("THOST_FTDC_BRF_BankBeenRepealed") = "2";
    consts.attr("THOST_FTDC_BRORF_BrokerNotNeedRepeal") = "0";
    consts.attr("THOST_FTDC_BRORF_BrokerWaitingRepeal") = "1";
    consts.attr("THOST_FTDC_BRORF_BrokerBeenRepealed") = "2";
    consts.attr("THOST_FTDC_TS_Bank") = "0";
    consts.attr("THOST_FTDC_TS_Future") = "1";
    consts.attr("THOST_FTDC_TS_Store") = "2";
    consts.attr("THOST_FTDC_LF_Yes") = "0";
    consts.attr("THOST_FTDC_LF_No") = "1";
    consts.attr("THOST_FTDC_BAS_Normal") = "0";
    consts.attr("THOST_FTDC_BAS_Freeze") = "1";
    consts.attr("THOST_FTDC_BAS_ReportLoss") = "2";
    consts.attr("THOST_FTDC_MAS_Normal") = "0";
    consts.attr("THOST_FTDC_MAS_Cancel") = "1";
    consts.attr("THOST_FTDC_MSS_Point") = "0";
    consts.attr("THOST_FTDC_MSS_PrePoint") = "1";
    consts.attr("THOST_FTDC_MSS_CancelPoint") = "2";
    consts.attr("THOST_FTDC_SYT_FutureBankTransfer") = "0";
    consts.attr("THOST_FTDC_SYT_StockBankTransfer") = "1";
    consts.attr("THOST_FTDC_SYT_TheThirdPartStore") = "2";
    consts.attr("THOST_FTDC_TEF_NormalProcessing") = "0";
    consts.attr("THOST_FTDC_TEF_Success") = "1";
    consts.attr("THOST_FTDC_TEF_Failed") = "2";
    consts.attr("THOST_FTDC_TEF_Abnormal") = "3";
    consts.attr("THOST_FTDC_TEF_ManualProcessedForException") = "4";
    consts.attr("THOST_FTDC_TEF_CommuFailedNeedManualProcess") = "5";
    consts.attr("THOST_FTDC_TEF_SysErrorNeedManualProcess") = "6";
    consts.attr("THOST_FTDC_PSS_NotProcess") = "0";
    consts.attr("THOST_FTDC_PSS_StartProcess") = "1";
    consts.attr("THOST_FTDC_PSS_Finished") = "2";
    consts.attr("THOST_FTDC_CUSTT_Person") = "0";
    consts.attr("THOST_FTDC_CUSTT_Institution") = "1";
    consts.attr("THOST_FTDC_FBTTD_FromBankToFuture") = "1";
    consts.attr("THOST_FTDC_FBTTD_FromFutureToBank") = "2";
    consts.attr("THOST_FTDC_OOD_Open") = "1";
    consts.attr("THOST_FTDC_OOD_Destroy") = "0";
    consts.attr("THOST_FTDC_AVAF_Invalid") = "0";
    consts.attr("THOST_FTDC_AVAF_Valid") = "1";
    consts.attr("THOST_FTDC_AVAF_Repeal") = "2";
    consts.attr("THOST_FTDC_OT_Bank") = "1";
    consts.attr("THOST_FTDC_OT_Future") = "2";
    consts.attr("THOST_FTDC_OT_PlateForm") = "9";
    consts.attr("THOST_FTDC_OL_HeadQuarters") = "1";
    consts.attr("THOST_FTDC_OL_Branch") = "2";
    consts.attr("THOST_FTDC_PID_FutureProtocal") = "0";
    consts.attr("THOST_FTDC_PID_ICBCProtocal") = "1";
    consts.attr("THOST_FTDC_PID_ABCProtocal") = "2";
    consts.attr("THOST_FTDC_PID_CBCProtocal") = "3";
    consts.attr("THOST_FTDC_PID_CCBProtocal") = "4";
    consts.attr("THOST_FTDC_PID_BOCOMProtocal") = "5";
    consts.attr("THOST_FTDC_PID_FBTPlateFormProtocal") = "X";
    consts.attr("THOST_FTDC_CM_ShortConnect") = "0";
    consts.attr("THOST_FTDC_CM_LongConnect") = "1";
    consts.attr("THOST_FTDC_SRM_ASync") = "0";
    consts.attr("THOST_FTDC_SRM_Sync") = "1";
    consts.attr("THOST_FTDC_BAT_BankBook") = "1";
    consts.attr("THOST_FTDC_BAT_SavingCard") = "2";
    consts.attr("THOST_FTDC_BAT_CreditCard") = "3";
    consts.attr("THOST_FTDC_FAT_BankBook") = "1";
    consts.attr("THOST_FTDC_FAT_SavingCard") = "2";
    consts.attr("THOST_FTDC_FAT_CreditCard") = "3";
    consts.attr("THOST_FTDC_OS_Ready") = "0";
    consts.attr("THOST_FTDC_OS_CheckIn") = "1";
    consts.attr("THOST_FTDC_OS_CheckOut") = "2";
    consts.attr("THOST_FTDC_OS_CheckFileArrived") = "3";
    consts.attr("THOST_FTDC_OS_CheckDetail") = "4";
    consts.attr("THOST_FTDC_OS_DayEndClean") = "5";
    consts.attr("THOST_FTDC_OS_Invalid") = "9";
    consts.attr("THOST_FTDC_CCBFM_ByAmount") = "1";
    consts.attr("THOST_FTDC_CCBFM_ByMonth") = "2";
    consts.attr("THOST_FTDC_CAPIT_Client") = "1";
    consts.attr("THOST_FTDC_CAPIT_Server") = "2";
    consts.attr("THOST_FTDC_CAPIT_UserApi") = "3";
    consts.attr("THOST_FTDC_LS_Connected") = "1";
    consts.attr("THOST_FTDC_LS_Disconnected") = "2";
    consts.attr("THOST_FTDC_BPWDF_NoCheck") = "0";
    consts.attr("THOST_FTDC_BPWDF_BlankCheck") = "1";
    consts.attr("THOST_FTDC_BPWDF_EncryptCheck") = "2";
    consts.attr("THOST_FTDC_SAT_AccountID") = "1";
    consts.attr("THOST_FTDC_SAT_CardID") = "2";
    consts.attr("THOST_FTDC_SAT_SHStockholderID") = "3";
    consts.attr("THOST_FTDC_SAT_SZStockholderID") = "4";
    consts.attr("THOST_FTDC_TRFS_Normal") = "0";
    consts.attr("THOST_FTDC_TRFS_Repealed") = "1";
    consts.attr("THOST_FTDC_SPTYPE_Broker") = "0";
    consts.attr("THOST_FTDC_SPTYPE_Bank") = "1";
    consts.attr("THOST_FTDC_REQRSP_Request") = "0";
    consts.attr("THOST_FTDC_REQRSP_Response") = "1";
    consts.attr("THOST_FTDC_FBTUET_SignIn") = "0";
    consts.attr("THOST_FTDC_FBTUET_FromBankToFuture") = "1";
    consts.attr("THOST_FTDC_FBTUET_FromFutureToBank") = "2";
    consts.attr("THOST_FTDC_FBTUET_OpenAccount") = "3";
    consts.attr("THOST_FTDC_FBTUET_CancelAccount") = "4";
    consts.attr("THOST_FTDC_FBTUET_ChangeAccount") = "5";
    consts.attr("THOST_FTDC_FBTUET_RepealFromBankToFuture") = "6";
    consts.attr("THOST_FTDC_FBTUET_RepealFromFutureToBank") = "7";
    consts.attr("THOST_FTDC_FBTUET_QueryBankAccount") = "8";
    consts.attr("THOST_FTDC_FBTUET_QueryFutureAccount") = "9";
    consts.attr("THOST_FTDC_FBTUET_SignOut") = "A";
    consts.attr("THOST_FTDC_FBTUET_SyncKey") = "B";
    consts.attr("THOST_FTDC_FBTUET_ReserveOpenAccount") = "C";
    consts.attr("THOST_FTDC_FBTUET_CancelReserveOpenAccount") = "D";
    consts.attr("THOST_FTDC_FBTUET_ReserveOpenAccountConfirm") = "E";
    consts.attr("THOST_FTDC_FBTUET_Other") = "Z";
    consts.attr("THOST_FTDC_DBOP_Insert") = "0";
    consts.attr("THOST_FTDC_DBOP_Update") = "1";
    consts.attr("THOST_FTDC_DBOP_Delete") = "2";
    consts.attr("THOST_FTDC_SYNF_Yes") = "0";
    consts.attr("THOST_FTDC_SYNF_No") = "1";
    consts.attr("THOST_FTDC_SYNT_OneOffSync") = "0";
    consts.attr("THOST_FTDC_SYNT_TimerSync") = "1";
    consts.attr("THOST_FTDC_SYNT_TimerFullSync") = "2";
    consts.attr("THOST_FTDC_FBEDIR_Settlement") = "0";
    consts.attr("THOST_FTDC_FBEDIR_Sale") = "1";
    consts.attr("THOST_FTDC_FBERES_Success") = "0";
    consts.attr("THOST_FTDC_FBERES_InsufficientBalance") = "1";
    consts.attr("THOST_FTDC_FBERES_UnknownTrading") = "8";
    consts.attr("THOST_FTDC_FBERES_Fail") = "x";
    consts.attr("THOST_FTDC_FBEES_Normal") = "0";
    consts.attr("THOST_FTDC_FBEES_ReExchange") = "1";
    consts.attr("THOST_FTDC_FBEFG_DataPackage") = "0";
    consts.attr("THOST_FTDC_FBEFG_File") = "1";
    consts.attr("THOST_FTDC_FBEAT_NotTrade") = "0";
    consts.attr("THOST_FTDC_FBEAT_Trade") = "1";
    consts.attr("THOST_FTDC_FBEUET_SignIn") = "0";
    consts.attr("THOST_FTDC_FBEUET_Exchange") = "1";
    consts.attr("THOST_FTDC_FBEUET_ReExchange") = "2";
    consts.attr("THOST_FTDC_FBEUET_QueryBankAccount") = "3";
    consts.attr("THOST_FTDC_FBEUET_QueryExchDetial") = "4";
    consts.attr("THOST_FTDC_FBEUET_QueryExchSummary") = "5";
    consts.attr("THOST_FTDC_FBEUET_QueryExchRate") = "6";
    consts.attr("THOST_FTDC_FBEUET_CheckBankAccount") = "7";
    consts.attr("THOST_FTDC_FBEUET_SignOut") = "8";
    consts.attr("THOST_FTDC_FBEUET_Other") = "Z";
    consts.attr("THOST_FTDC_FBERF_UnProcessed") = "0";
    consts.attr("THOST_FTDC_FBERF_WaitSend") = "1";
    consts.attr("THOST_FTDC_FBERF_SendSuccess") = "2";
    consts.attr("THOST_FTDC_FBERF_SendFailed") = "3";
    consts.attr("THOST_FTDC_FBERF_WaitReSend") = "4";
    consts.attr("THOST_FTDC_NC_NOERROR") = "0";
    consts.attr("THOST_FTDC_NC_Warn") = "1";
    consts.attr("THOST_FTDC_NC_Call") = "2";
    consts.attr("THOST_FTDC_NC_Force") = "3";
    consts.attr("THOST_FTDC_NC_CHUANCANG") = "4";
    consts.attr("THOST_FTDC_NC_Exception") = "5";
    consts.attr("THOST_FTDC_FCT_Manual") = "0";
    consts.attr("THOST_FTDC_FCT_Single") = "1";
    consts.attr("THOST_FTDC_FCT_Group") = "2";
    consts.attr("THOST_FTDC_RNM_System") = "0";
    consts.attr("THOST_FTDC_RNM_SMS") = "1";
    consts.attr("THOST_FTDC_RNM_EMail") = "2";
    consts.attr("THOST_FTDC_RNM_Manual") = "3";
    consts.attr("THOST_FTDC_RNS_NotGen") = "0";
    consts.attr("THOST_FTDC_RNS_Generated") = "1";
    consts.attr("THOST_FTDC_RNS_SendError") = "2";
    consts.attr("THOST_FTDC_RNS_SendOk") = "3";
    consts.attr("THOST_FTDC_RNS_Received") = "4";
    consts.attr("THOST_FTDC_RNS_Confirmed") = "5";
    consts.attr("THOST_FTDC_RUE_ExportData") = "0";
    consts.attr("THOST_FTDC_COST_LastPriceAsc") = "0";
    consts.attr("THOST_FTDC_COST_LastPriceDesc") = "1";
    consts.attr("THOST_FTDC_COST_AskPriceAsc") = "2";
    consts.attr("THOST_FTDC_COST_AskPriceDesc") = "3";
    consts.attr("THOST_FTDC_COST_BidPriceAsc") = "4";
    consts.attr("THOST_FTDC_COST_BidPriceDesc") = "5";
    consts.attr("THOST_FTDC_UOAST_NoSend") = "0";
    consts.attr("THOST_FTDC_UOAST_Sended") = "1";
    consts.attr("THOST_FTDC_UOAST_Generated") = "2";
    consts.attr("THOST_FTDC_UOAST_SendFail") = "3";
    consts.attr("THOST_FTDC_UOAST_Success") = "4";
    consts.attr("THOST_FTDC_UOAST_Fail") = "5";
    consts.attr("THOST_FTDC_UOAST_Cancel") = "6";
    consts.attr("THOST_FTDC_UOACS_NoApply") = "1";
    consts.attr("THOST_FTDC_UOACS_Submited") = "2";
    consts.attr("THOST_FTDC_UOACS_Sended") = "3";
    consts.attr("THOST_FTDC_UOACS_Success") = "4";
    consts.attr("THOST_FTDC_UOACS_Refuse") = "5";
    consts.attr("THOST_FTDC_UOACS_Cancel") = "6";
    consts.attr("THOST_FTDC_QT_Radio") = "1";
    consts.attr("THOST_FTDC_QT_Option") = "2";
    consts.attr("THOST_FTDC_QT_Blank") = "3";
    consts.attr("THOST_FTDC_BT_Request") = "1";
    consts.attr("THOST_FTDC_BT_Response") = "2";
    consts.attr("THOST_FTDC_BT_Notice") = "3";
    consts.attr("THOST_FTDC_CRC_Success") = "0";
    consts.attr("THOST_FTDC_CRC_Working") = "1";
    consts.attr("THOST_FTDC_CRC_InfoFail") = "2";
    consts.attr("THOST_FTDC_CRC_IDCardFail") = "3";
    consts.attr("THOST_FTDC_CRC_OtherFail") = "4";
    consts.attr("THOST_FTDC_CfMMCCT_All") = "0";
    consts.attr("THOST_FTDC_CfMMCCT_Person") = "1";
    consts.attr("THOST_FTDC_CfMMCCT_Company") = "2";
    consts.attr("THOST_FTDC_CfMMCCT_Other") = "3";
    consts.attr("THOST_FTDC_CfMMCCT_SpecialOrgan") = "4";
    consts.attr("THOST_FTDC_CfMMCCT_Asset") = "5";
    consts.attr("THOST_FTDC_EIDT_SHFE") = "S";
    consts.attr("THOST_FTDC_EIDT_CZCE") = "Z";
    consts.attr("THOST_FTDC_EIDT_DCE") = "D";
    consts.attr("THOST_FTDC_EIDT_CFFEX") = "J";
    consts.attr("THOST_FTDC_EIDT_INE") = "N";
    consts.attr("THOST_FTDC_ECIDT_Hedge") = "1";
    consts.attr("THOST_FTDC_ECIDT_Arbitrage") = "2";
    consts.attr("THOST_FTDC_ECIDT_Speculation") = "3";
    consts.attr("THOST_FTDC_UF_NoUpdate") = "0";
    consts.attr("THOST_FTDC_UF_Success") = "1";
    consts.attr("THOST_FTDC_UF_Fail") = "2";
    consts.attr("THOST_FTDC_UF_TCSuccess") = "3";
    consts.attr("THOST_FTDC_UF_TCFail") = "4";
    consts.attr("THOST_FTDC_UF_Cancel") = "5";
    consts.attr("THOST_FTDC_AOID_OpenInvestor") = "1";
    consts.attr("THOST_FTDC_AOID_ModifyIDCard") = "2";
    consts.attr("THOST_FTDC_AOID_ModifyNoIDCard") = "3";
    consts.attr("THOST_FTDC_AOID_ApplyTradingCode") = "4";
    consts.attr("THOST_FTDC_AOID_CancelTradingCode") = "5";
    consts.attr("THOST_FTDC_AOID_CancelInvestor") = "6";
    consts.attr("THOST_FTDC_AOID_FreezeAccount") = "8";
    consts.attr("THOST_FTDC_AOID_ActiveFreezeAccount") = "9";
    consts.attr("THOST_FTDC_ASID_NoComplete") = "1";
    consts.attr("THOST_FTDC_ASID_Submited") = "2";
    consts.attr("THOST_FTDC_ASID_Checked") = "3";
    consts.attr("THOST_FTDC_ASID_Refused") = "4";
    consts.attr("THOST_FTDC_ASID_Deleted") = "5";
    consts.attr("THOST_FTDC_UOASM_ByAPI") = "1";
    consts.attr("THOST_FTDC_UOASM_ByFile") = "2";
    consts.attr("THOST_FTDC_EvM_ADD") = "1";
    consts.attr("THOST_FTDC_EvM_UPDATE") = "2";
    consts.attr("THOST_FTDC_EvM_DELETE") = "3";
    consts.attr("THOST_FTDC_EvM_CHECK") = "4";
    consts.attr("THOST_FTDC_EvM_COPY") = "5";
    consts.attr("THOST_FTDC_EvM_CANCEL") = "6";
    consts.attr("THOST_FTDC_EvM_Reverse") = "7";
    consts.attr("THOST_FTDC_UOAA_ASR") = "1";
    consts.attr("THOST_FTDC_UOAA_ASNR") = "2";
    consts.attr("THOST_FTDC_UOAA_NSAR") = "3";
    consts.attr("THOST_FTDC_UOAA_NSR") = "4";
    consts.attr("THOST_FTDC_EvM_InvestorGroupFlow") = "1";
    consts.attr("THOST_FTDC_EvM_InvestorRate") = "2";
    consts.attr("THOST_FTDC_EvM_InvestorCommRateModel") = "3";
    consts.attr("THOST_FTDC_CL_Zero") = "0";
    consts.attr("THOST_FTDC_CL_One") = "1";
    consts.attr("THOST_FTDC_CL_Two") = "2";
    consts.attr("THOST_FTDC_CHS_Init") = "0";
    consts.attr("THOST_FTDC_CHS_Checking") = "1";
    consts.attr("THOST_FTDC_CHS_Checked") = "2";
    consts.attr("THOST_FTDC_CHS_Refuse") = "3";
    consts.attr("THOST_FTDC_CHS_Cancel") = "4";
    consts.attr("THOST_FTDC_CHU_Unused") = "0";
    consts.attr("THOST_FTDC_CHU_Used") = "1";
    consts.attr("THOST_FTDC_CHU_Fail") = "2";
    consts.attr("THOST_FTDC_BAO_ByAccProperty") = "0";
    consts.attr("THOST_FTDC_BAO_ByFBTransfer") = "1";
    consts.attr("THOST_FTDC_MBTS_ByInstrument") = "0";
    consts.attr("THOST_FTDC_MBTS_ByDayInsPrc") = "1";
    consts.attr("THOST_FTDC_MBTS_ByDayIns") = "2";
    consts.attr("THOST_FTDC_FTC_BankLaunchBankToBroker") = "102001";
    consts.attr("THOST_FTDC_FTC_BrokerLaunchBankToBroker") = "202001";
    consts.attr("THOST_FTDC_FTC_BankLaunchBrokerToBank") = "102002";
    consts.attr("THOST_FTDC_FTC_BrokerLaunchBrokerToBank") = "202002";
    consts.attr("THOST_FTDC_OTP_NONE") = "0";
    consts.attr("THOST_FTDC_OTP_TOTP") = "1";
    consts.attr("THOST_FTDC_OTPS_Unused") = "0";
    consts.attr("THOST_FTDC_OTPS_Used") = "1";
    consts.attr("THOST_FTDC_OTPS_Disuse") = "2";
    consts.attr("THOST_FTDC_BUT_Investor") = "1";
    consts.attr("THOST_FTDC_BUT_BrokerUser") = "2";
    consts.attr("THOST_FTDC_FUTT_Commodity") = "1";
    consts.attr("THOST_FTDC_FUTT_Financial") = "2";
    consts.attr("THOST_FTDC_FET_Restriction") = "0";
    consts.attr("THOST_FTDC_FET_TodayRestriction") = "1";
    consts.attr("THOST_FTDC_FET_Transfer") = "2";
    consts.attr("THOST_FTDC_FET_Credit") = "3";
    consts.attr("THOST_FTDC_FET_InvestorWithdrawAlm") = "4";
    consts.attr("THOST_FTDC_FET_BankRestriction") = "5";
    consts.attr("THOST_FTDC_FET_Accountregister") = "6";
    consts.attr("THOST_FTDC_FET_ExchangeFundIO") = "7";
    consts.attr("THOST_FTDC_FET_InvestorFundIO") = "8";
    consts.attr("THOST_FTDC_AST_FBTransfer") = "0";
    consts.attr("THOST_FTDC_AST_ManualEntry") = "1";
    consts.attr("THOST_FTDC_CST_UnifyAccount") = "0";
    consts.attr("THOST_FTDC_CST_ManualEntry") = "1";
    consts.attr("THOST_FTDC_UR_All") = "0";
    consts.attr("THOST_FTDC_UR_Single") = "1";
    consts.attr("THOST_FTDC_BG_Investor") = "2";
    consts.attr("THOST_FTDC_BG_Group") = "1";
    consts.attr("THOST_FTDC_TSSM_Instrument") = "1";
    consts.attr("THOST_FTDC_TSSM_Product") = "2";
    consts.attr("THOST_FTDC_TSSM_Exchange") = "3";
    consts.attr("THOST_FTDC_ESM_Relative") = "1";
    consts.attr("THOST_FTDC_ESM_Typical") = "2";
    consts.attr("THOST_FTDC_RIR_All") = "1";
    consts.attr("THOST_FTDC_RIR_Model") = "2";
    consts.attr("THOST_FTDC_RIR_Single") = "3";
    consts.attr("THOST_FTDC_SDS_Initialize") = "0";
    consts.attr("THOST_FTDC_SDS_Settlementing") = "1";
    consts.attr("THOST_FTDC_SDS_Settlemented") = "2";
    consts.attr("THOST_FTDC_TSRC_NORMAL") = "0";
    consts.attr("THOST_FTDC_TSRC_QUERY") = "1";
    consts.attr("THOST_FTDC_FSM_Product") = "1";
    consts.attr("THOST_FTDC_FSM_Exchange") = "2";
    consts.attr("THOST_FTDC_FSM_All") = "3";
    consts.attr("THOST_FTDC_BIR_Property") = "1";
    consts.attr("THOST_FTDC_BIR_All") = "2";
    consts.attr("THOST_FTDC_PIR_All") = "1";
    consts.attr("THOST_FTDC_PIR_Property") = "2";
    consts.attr("THOST_FTDC_PIR_Single") = "3";
    consts.attr("THOST_FTDC_FIS_NoCreate") = "0";
    consts.attr("THOST_FTDC_FIS_Created") = "1";
    consts.attr("THOST_FTDC_FIS_Failed") = "2";
    consts.attr("THOST_FTDC_FGS_FileTransmit") = "0";
    consts.attr("THOST_FTDC_FGS_FileGen") = "1";
    consts.attr("THOST_FTDC_SoM_Add") = "1";
    consts.attr("THOST_FTDC_SoM_Update") = "2";
    consts.attr("THOST_FTDC_SoM_Delete") = "3";
    consts.attr("THOST_FTDC_SoM_Copy") = "4";
    consts.attr("THOST_FTDC_SoM_AcTive") = "5";
    consts.attr("THOST_FTDC_SoM_CanCel") = "6";
    consts.attr("THOST_FTDC_SoM_ReSet") = "7";
    consts.attr("THOST_FTDC_SoT_UpdatePassword") = "0";
    consts.attr("THOST_FTDC_SoT_UserDepartment") = "1";
    consts.attr("THOST_FTDC_SoT_RoleManager") = "2";
    consts.attr("THOST_FTDC_SoT_RoleFunction") = "3";
    consts.attr("THOST_FTDC_SoT_BaseParam") = "4";
    consts.attr("THOST_FTDC_SoT_SetUserID") = "5";
    consts.attr("THOST_FTDC_SoT_SetUserRole") = "6";
    consts.attr("THOST_FTDC_SoT_UserIpRestriction") = "7";
    consts.attr("THOST_FTDC_SoT_DepartmentManager") = "8";
    consts.attr("THOST_FTDC_SoT_DepartmentCopy") = "9";
    consts.attr("THOST_FTDC_SoT_Tradingcode") = "A";
    consts.attr("THOST_FTDC_SoT_InvestorStatus") = "B";
    consts.attr("THOST_FTDC_SoT_InvestorAuthority") = "C";
    consts.attr("THOST_FTDC_SoT_PropertySet") = "D";
    consts.attr("THOST_FTDC_SoT_ReSetInvestorPasswd") = "E";
    consts.attr("THOST_FTDC_SoT_InvestorPersonalityInfo") = "F";
    consts.attr("THOST_FTDC_CSRCQ_Current") = "0";
    consts.attr("THOST_FTDC_CSRCQ_History") = "1";
    consts.attr("THOST_FTDC_FRS_Normal") = "1";
    consts.attr("THOST_FTDC_FRS_Freeze") = "0";
    consts.attr("THOST_FTDC_STST_Standard") = "0";
    consts.attr("THOST_FTDC_STST_NonStandard") = "1";
    consts.attr("THOST_FTDC_RPT_Freeze") = "1";
    consts.attr("THOST_FTDC_RPT_FreezeActive") = "2";
    consts.attr("THOST_FTDC_RPT_OpenLimit") = "3";
    consts.attr("THOST_FTDC_RPT_RelieveOpenLimit") = "4";
    consts.attr("THOST_FTDC_AMLDS_Normal") = "0";
    consts.attr("THOST_FTDC_AMLDS_Deleted") = "1";
    consts.attr("THOST_FTDC_AMLCHS_Init") = "0";
    consts.attr("THOST_FTDC_AMLCHS_Checking") = "1";
    consts.attr("THOST_FTDC_AMLCHS_Checked") = "2";
    consts.attr("THOST_FTDC_AMLCHS_RefuseReport") = "3";
    consts.attr("THOST_FTDC_AMLDT_DrawDay") = "0";
    consts.attr("THOST_FTDC_AMLDT_TouchDay") = "1";
    consts.attr("THOST_FTDC_AMLCL_CheckLevel0") = "0";
    consts.attr("THOST_FTDC_AMLCL_CheckLevel1") = "1";
    consts.attr("THOST_FTDC_AMLCL_CheckLevel2") = "2";
    consts.attr("THOST_FTDC_AMLCL_CheckLevel3") = "3";
    consts.attr("THOST_FTDC_EFT_CSV") = "0";
    consts.attr("THOST_FTDC_EFT_EXCEL") = "1";
    consts.attr("THOST_FTDC_EFT_DBF") = "2";
    consts.attr("THOST_FTDC_SMT_Before") = "1";
    consts.attr("THOST_FTDC_SMT_Settlement") = "2";
    consts.attr("THOST_FTDC_SMT_After") = "3";
    consts.attr("THOST_FTDC_SMT_Settlemented") = "4";
    consts.attr("THOST_FTDC_SML_Must") = "1";
    consts.attr("THOST_FTDC_SML_Alarm") = "2";
    consts.attr("THOST_FTDC_SML_Prompt") = "3";
    consts.attr("THOST_FTDC_SML_Ignore") = "4";
    consts.attr("THOST_FTDC_SMG_Exhcange") = "1";
    consts.attr("THOST_FTDC_SMG_ASP") = "2";
    consts.attr("THOST_FTDC_SMG_CSRC") = "3";
    consts.attr("THOST_FTDC_LUT_Repeatable") = "1";
    consts.attr("THOST_FTDC_LUT_Unrepeatable") = "2";
    consts.attr("THOST_FTDC_DAR_Settle") = "1";
    consts.attr("THOST_FTDC_DAR_Exchange") = "2";
    consts.attr("THOST_FTDC_DAR_CSRC") = "3";
    consts.attr("THOST_FTDC_MGT_ExchMarginRate") = "0";
    consts.attr("THOST_FTDC_MGT_InstrMarginRate") = "1";
    consts.attr("THOST_FTDC_MGT_InstrMarginRateTrade") = "2";
    consts.attr("THOST_FTDC_ACT_Intraday") = "1";
    consts.attr("THOST_FTDC_ACT_Long") = "2";
    consts.attr("THOST_FTDC_MRT_Exchange") = "1";
    consts.attr("THOST_FTDC_MRT_Investor") = "2";
    consts.attr("THOST_FTDC_MRT_InvestorTrade") = "3";
    consts.attr("THOST_FTDC_BUS_UnBak") = "0";
    consts.attr("THOST_FTDC_BUS_BakUp") = "1";
    consts.attr("THOST_FTDC_BUS_BakUped") = "2";
    consts.attr("THOST_FTDC_BUS_BakFail") = "3";
    consts.attr("THOST_FTDC_SIS_UnInitialize") = "0";
    consts.attr("THOST_FTDC_SIS_Initialize") = "1";
    consts.attr("THOST_FTDC_SIS_Initialized") = "2";
    consts.attr("THOST_FTDC_SRS_NoCreate") = "0";
    consts.attr("THOST_FTDC_SRS_Create") = "1";
    consts.attr("THOST_FTDC_SRS_Created") = "2";
    consts.attr("THOST_FTDC_SRS_CreateFail") = "3";
    consts.attr("THOST_FTDC_SSS_UnSaveData") = "0";
    consts.attr("THOST_FTDC_SSS_SaveDatad") = "1";
    consts.attr("THOST_FTDC_SAS_UnArchived") = "0";
    consts.attr("THOST_FTDC_SAS_Archiving") = "1";
    consts.attr("THOST_FTDC_SAS_Archived") = "2";
    consts.attr("THOST_FTDC_SAS_ArchiveFail") = "3";
    consts.attr("THOST_FTDC_CTPT_Unkown") = "0";
    consts.attr("THOST_FTDC_CTPT_MainCenter") = "1";
    consts.attr("THOST_FTDC_CTPT_BackUp") = "2";
    consts.attr("THOST_FTDC_CDT_Normal") = "0";
    consts.attr("THOST_FTDC_CDT_SpecFirst") = "1";
    consts.attr("THOST_FTDC_MFUR_None") = "0";
    consts.attr("THOST_FTDC_MFUR_Margin") = "1";
    consts.attr("THOST_FTDC_MFUR_All") = "2";
    consts.attr("THOST_FTDC_MFUR_CNY3") = "3";
    consts.attr("THOST_FTDC_SPT_CzceHedge") = "1";
    consts.attr("THOST_FTDC_SPT_IneForeignCurrency") = "2";
    consts.attr("THOST_FTDC_SPT_DceOpenClose") = "3";
    consts.attr("THOST_FTDC_FMT_Mortgage") = "1";
    consts.attr("THOST_FTDC_FMT_Redemption") = "2";
    consts.attr("THOST_FTDC_ASPI_BaseMargin") = "1";
    consts.attr("THOST_FTDC_ASPI_LowestInterest") = "2";
    consts.attr("THOST_FTDC_FMD_In") = "1";
    consts.attr("THOST_FTDC_FMD_Out") = "2";
    consts.attr("THOST_FTDC_BT_Profit") = "0";
    consts.attr("THOST_FTDC_BT_Loss") = "1";
    consts.attr("THOST_FTDC_BT_Other") = "Z";
    consts.attr("THOST_FTDC_SST_Manual") = "0";
    consts.attr("THOST_FTDC_SST_Automatic") = "1";
    consts.attr("THOST_FTDC_CED_Settlement") = "0";
    consts.attr("THOST_FTDC_CED_Sale") = "1";
    consts.attr("THOST_FTDC_CSS_Entry") = "1";
    consts.attr("THOST_FTDC_CSS_Approve") = "2";
    consts.attr("THOST_FTDC_CSS_Refuse") = "3";
    consts.attr("THOST_FTDC_CSS_Revoke") = "4";
    consts.attr("THOST_FTDC_CSS_Send") = "5";
    consts.attr("THOST_FTDC_CSS_Success") = "6";
    consts.attr("THOST_FTDC_CSS_Failure") = "7";
    consts.attr("THOST_FTDC_REQF_NoSend") = "0";
    consts.attr("THOST_FTDC_REQF_SendSuccess") = "1";
    consts.attr("THOST_FTDC_REQF_SendFailed") = "2";
    consts.attr("THOST_FTDC_REQF_WaitReSend") = "3";
    consts.attr("THOST_FTDC_RESF_Success") = "0";
    consts.attr("THOST_FTDC_RESF_InsuffiCient") = "1";
    consts.attr("THOST_FTDC_RESF_UnKnown") = "8";
    consts.attr("THOST_FTDC_EXS_Before") = "0";
    consts.attr("THOST_FTDC_EXS_After") = "1";
    consts.attr("THOST_FTDC_CR_Domestic") = "1";
    consts.attr("THOST_FTDC_CR_GMT") = "2";
    consts.attr("THOST_FTDC_CR_Foreign") = "3";
    consts.attr("THOST_FTDC_HB_No") = "0";
    consts.attr("THOST_FTDC_HB_Yes") = "1";
    consts.attr("THOST_FTDC_SM_Normal") = "1";
    consts.attr("THOST_FTDC_SM_Emerge") = "2";
    consts.attr("THOST_FTDC_SM_Restore") = "3";
    consts.attr("THOST_FTDC_TPT_Full") = "1";
    consts.attr("THOST_FTDC_TPT_Increment") = "2";
    consts.attr("THOST_FTDC_TPT_BackUp") = "3";
    consts.attr("THOST_FTDC_LM_Trade") = "0";
    consts.attr("THOST_FTDC_LM_Transfer") = "1";
    consts.attr("THOST_FTDC_CPT_Instrument") = "1";
    consts.attr("THOST_FTDC_CPT_Margin") = "2";
    consts.attr("THOST_FTDC_HT_Yes") = "1";
    consts.attr("THOST_FTDC_HT_No") = "0";
    consts.attr("THOST_FTDC_AMT_Bank") = "1";
    consts.attr("THOST_FTDC_AMT_Securities") = "2";
    consts.attr("THOST_FTDC_AMT_Fund") = "3";
    consts.attr("THOST_FTDC_AMT_Insurance") = "4";
    consts.attr("THOST_FTDC_AMT_Trust") = "5";
    consts.attr("THOST_FTDC_AMT_Other") = "9";
    consts.attr("THOST_FTDC_CFIOT_FundIO") = "0";
    consts.attr("THOST_FTDC_CFIOT_SwapCurrency") = "1";
    consts.attr("THOST_FTDC_CAT_Futures") = "1";
    consts.attr("THOST_FTDC_CAT_AssetmgrFuture") = "2";
    consts.attr("THOST_FTDC_CAT_AssetmgrTrustee") = "3";
    consts.attr("THOST_FTDC_CAT_AssetmgrTransfer") = "4";
    consts.attr("THOST_FTDC_LT_Chinese") = "1";
    consts.attr("THOST_FTDC_LT_English") = "2";
    consts.attr("THOST_FTDC_AMCT_Person") = "1";
    consts.attr("THOST_FTDC_AMCT_Organ") = "2";
    consts.attr("THOST_FTDC_AMCT_SpecialOrgan") = "4";
    consts.attr("THOST_FTDC_ASST_Futures") = "3";
    consts.attr("THOST_FTDC_ASST_SpecialOrgan") = "4";
    consts.attr("THOST_FTDC_CIT_HasExch") = "0";
    consts.attr("THOST_FTDC_CIT_HasATP") = "1";
    consts.attr("THOST_FTDC_CIT_HasDiff") = "2";
    consts.attr("THOST_FTDC_DT_HandDeliv") = "1";
    consts.attr("THOST_FTDC_DT_PersonDeliv") = "2";
    consts.attr("THOST_FTDC_MMSA_NO") = "0";
    consts.attr("THOST_FTDC_MMSA_YES") = "1";
    consts.attr("THOST_FTDC_CACT_Person") = "0";
    consts.attr("THOST_FTDC_CACT_Company") = "1";
    consts.attr("THOST_FTDC_CACT_Other") = "2";
    consts.attr("THOST_FTDC_UOAAT_Futures") = "1";
    consts.attr("THOST_FTDC_UOAAT_SpecialOrgan") = "2";
    consts.attr("THOST_FTDC_DEN_Buy") = "0";
    consts.attr("THOST_FTDC_DEN_Sell") = "1";
    consts.attr("THOST_FTDC_OFEN_Open") = "0";
    consts.attr("THOST_FTDC_OFEN_Close") = "1";
    consts.attr("THOST_FTDC_OFEN_ForceClose") = "2";
    consts.attr("THOST_FTDC_OFEN_CloseToday") = "3";
    consts.attr("THOST_FTDC_OFEN_CloseYesterday") = "4";
    consts.attr("THOST_FTDC_OFEN_ForceOff") = "5";
    consts.attr("THOST_FTDC_OFEN_LocalForceClose") = "6";
    consts.attr("THOST_FTDC_HFEN_Speculation") = "1";
    consts.attr("THOST_FTDC_HFEN_Arbitrage") = "2";
    consts.attr("THOST_FTDC_HFEN_Hedge") = "3";
    consts.attr("THOST_FTDC_FIOTEN_FundIO") = "1";
    consts.attr("THOST_FTDC_FIOTEN_Transfer") = "2";
    consts.attr("THOST_FTDC_FIOTEN_SwapCurrency") = "3";
    consts.attr("THOST_FTDC_FTEN_Deposite") = "1";
    consts.attr("THOST_FTDC_FTEN_ItemFund") = "2";
    consts.attr("THOST_FTDC_FTEN_Company") = "3";
    consts.attr("THOST_FTDC_FTEN_InnerTransfer") = "4";
    consts.attr("THOST_FTDC_FDEN_In") = "1";
    consts.attr("THOST_FTDC_FDEN_Out") = "2";
    consts.attr("THOST_FTDC_FMDEN_In") = "1";
    consts.attr("THOST_FTDC_FMDEN_Out") = "2";
    consts.attr("THOST_FTDC_CP_CallOptions") = "1";
    consts.attr("THOST_FTDC_CP_PutOptions") = "2";
    consts.attr("THOST_FTDC_STM_Continental") = "0";
    consts.attr("THOST_FTDC_STM_American") = "1";
    consts.attr("THOST_FTDC_STM_Bermuda") = "2";
    consts.attr("THOST_FTDC_STT_Hedge") = "0";
    consts.attr("THOST_FTDC_STT_Match") = "1";
    consts.attr("THOST_FTDC_APPT_NotStrikeNum") = "4";
    consts.attr("THOST_FTDC_GUDS_Gen") = "0";
    consts.attr("THOST_FTDC_GUDS_Hand") = "1";
    consts.attr("THOST_FTDC_OER_NoExec") = "n";
    consts.attr("THOST_FTDC_OER_Canceled") = "c";
    consts.attr("THOST_FTDC_OER_OK") = "0";
    consts.attr("THOST_FTDC_OER_NoPosition") = "1";
    consts.attr("THOST_FTDC_OER_NoDeposit") = "2";
    consts.attr("THOST_FTDC_OER_NoParticipant") = "3";
    consts.attr("THOST_FTDC_OER_NoClient") = "4";
    consts.attr("THOST_FTDC_OER_NoInstrument") = "6";
    consts.attr("THOST_FTDC_OER_NoRight") = "7";
    consts.attr("THOST_FTDC_OER_InvalidVolume") = "8";
    consts.attr("THOST_FTDC_OER_NoEnoughHistoryTrade") = "9";
    consts.attr("THOST_FTDC_OER_Unknown") = "a";
    consts.attr("THOST_FTDC_COMBT_Future") = "0";
    consts.attr("THOST_FTDC_COMBT_BUL") = "1";
    consts.attr("THOST_FTDC_COMBT_BER") = "2";
    consts.attr("THOST_FTDC_COMBT_STD") = "3";
    consts.attr("THOST_FTDC_COMBT_STG") = "4";
    consts.attr("THOST_FTDC_COMBT_PRT") = "5";
    consts.attr("THOST_FTDC_COMBT_CAS") = "6";
    consts.attr("THOST_FTDC_COMBT_OPL") = "7";
    consts.attr("THOST_FTDC_COMBT_BFO") = "8";
    consts.attr("THOST_FTDC_COMBT_BLS") = "9";
    consts.attr("THOST_FTDC_COMBT_BES") = "a";
    consts.attr("THOST_FTDC_DCECOMBT_SPL") = "0";
    consts.attr("THOST_FTDC_DCECOMBT_OPL") = "1";
    consts.attr("THOST_FTDC_DCECOMBT_SP") = "2";
    consts.attr("THOST_FTDC_DCECOMBT_SPC") = "3";
    consts.attr("THOST_FTDC_DCECOMBT_BLS") = "4";
    consts.attr("THOST_FTDC_DCECOMBT_BES") = "5";
    consts.attr("THOST_FTDC_DCECOMBT_CAS") = "6";
    consts.attr("THOST_FTDC_DCECOMBT_STD") = "7";
    consts.attr("THOST_FTDC_DCECOMBT_STG") = "8";
    consts.attr("THOST_FTDC_DCECOMBT_BFO") = "9";
    consts.attr("THOST_FTDC_DCECOMBT_SFO") = "a";
    consts.attr("THOST_FTDC_ORPT_PreSettlementPrice") = "1";
    consts.attr("THOST_FTDC_ORPT_OpenPrice") = "4";
    consts.attr("THOST_FTDC_ORPT_MaxPreSettlementPrice") = "5";
    consts.attr("THOST_FTDC_BLAG_Default") = "1";
    consts.attr("THOST_FTDC_BLAG_IncludeOptValLost") = "2";
    consts.attr("THOST_FTDC_ACTP_Exec") = "1";
    consts.attr("THOST_FTDC_ACTP_Abandon") = "2";
    consts.attr("THOST_FTDC_FQST_Submitted") = "a";
    consts.attr("THOST_FTDC_FQST_Accepted") = "b";
    consts.attr("THOST_FTDC_FQST_Rejected") = "c";
    consts.attr("THOST_FTDC_VM_Absolute") = "0";
    consts.attr("THOST_FTDC_VM_Ratio") = "1";
    consts.attr("THOST_FTDC_EOPF_Reserve") = "0";
    consts.attr("THOST_FTDC_EOPF_UnReserve") = "1";
    consts.attr("THOST_FTDC_EOCF_AutoClose") = "0";
    consts.attr("THOST_FTDC_EOCF_NotToClose") = "1";
    consts.attr("THOST_FTDC_PTE_Futures") = "1";
    consts.attr("THOST_FTDC_PTE_Options") = "2";
    consts.attr("THOST_FTDC_CUFN_CUFN_O") = "O";
    consts.attr("THOST_FTDC_CUFN_CUFN_T") = "T";
    consts.attr("THOST_FTDC_CUFN_CUFN_P") = "P";
    consts.attr("THOST_FTDC_CUFN_CUFN_N") = "N";
    consts.attr("THOST_FTDC_CUFN_CUFN_L") = "L";
    consts.attr("THOST_FTDC_CUFN_CUFN_F") = "F";
    consts.attr("THOST_FTDC_CUFN_CUFN_C") = "C";
    consts.attr("THOST_FTDC_CUFN_CUFN_M") = "M";
    consts.attr("THOST_FTDC_DUFN_DUFN_O") = "O";
    consts.attr("THOST_FTDC_DUFN_DUFN_T") = "T";
    consts.attr("THOST_FTDC_DUFN_DUFN_P") = "P";
    consts.attr("THOST_FTDC_DUFN_DUFN_F") = "F";
    consts.attr("THOST_FTDC_DUFN_DUFN_C") = "C";
    consts.attr("THOST_FTDC_DUFN_DUFN_D") = "D";
    consts.attr("THOST_FTDC_DUFN_DUFN_M") = "M";
    consts.attr("THOST_FTDC_DUFN_DUFN_S") = "S";
    consts.attr("THOST_FTDC_SUFN_SUFN_O") = "O";
    consts.attr("THOST_FTDC_SUFN_SUFN_T") = "T";
    consts.attr("THOST_FTDC_SUFN_SUFN_P") = "P";
    consts.attr("THOST_FTDC_SUFN_SUFN_F") = "F";
    consts.attr("THOST_FTDC_CFUFN_SUFN_T") = "T";
    consts.attr("THOST_FTDC_CFUFN_SUFN_P") = "P";
    consts.attr("THOST_FTDC_CFUFN_SUFN_F") = "F";
    consts.attr("THOST_FTDC_CFUFN_SUFN_S") = "S";
    consts.attr("THOST_FTDC_CMDR_Comb") = "0";
    consts.attr("THOST_FTDC_CMDR_UnComb") = "1";
    consts.attr("THOST_FTDC_CMDR_DelComb") = "2";
    consts.attr("THOST_FTDC_STOV_RealValue") = "1";
    consts.attr("THOST_FTDC_STOV_ProfitValue") = "2";
    consts.attr("THOST_FTDC_STOV_RealRatio") = "3";
    consts.attr("THOST_FTDC_STOV_ProfitRatio") = "4";
    consts.attr("THOST_FTDC_ROAST_Processing") = "0";
    consts.attr("THOST_FTDC_ROAST_Cancelled") = "1";
    consts.attr("THOST_FTDC_ROAST_Opened") = "2";
    consts.attr("THOST_FTDC_ROAST_Invalid") = "3";
    consts.attr("THOST_FTDC_WPSR_Lib") = "1";
    consts.attr("THOST_FTDC_WPSR_Manual") = "2";
    consts.attr("THOST_FTDC_OSCF_CloseSelfOptionPosition") = "1";
    consts.attr("THOST_FTDC_OSCF_ReserveOptionPosition") = "2";
    consts.attr("THOST_FTDC_OSCF_SellCloseSelfFuturePosition") = "3";
    consts.attr("THOST_FTDC_OSCF_ReserveFuturePosition") = "4";
    consts.attr("THOST_FTDC_BZTP_Future") = "1";
    consts.attr("THOST_FTDC_BZTP_Stock") = "2";
    consts.attr("THOST_FTDC_APP_TYPE_Investor") = "1";
    consts.attr("THOST_FTDC_APP_TYPE_InvestorRelay") = "2";
    consts.attr("THOST_FTDC_APP_TYPE_OperatorRelay") = "3";
    consts.attr("THOST_FTDC_APP_TYPE_UnKnown") = "4";
    consts.attr("THOST_FTDC_RV_Right") = "0";
    consts.attr("THOST_FTDC_RV_Refuse") = "1";
    consts.attr("THOST_FTDC_OTC_TRDT_Block") = "0";
    consts.attr("THOST_FTDC_OTC_TRDT_EFP") = "1";
    consts.attr("THOST_FTDC_OTC_MT_DV01") = "1";
    consts.attr("THOST_FTDC_OTC_MT_ParValue") = "2";
    consts.attr("THOST_FTDC_AU_WHITE") = "0";
    consts.attr("THOST_FTDC_AU_BLACK") = "1";
    consts.attr("THOST_FTDC_INS_ALL") = "0";
    consts.attr("THOST_FTDC_INS_FUTURE") = "1";
    consts.attr("THOST_FTDC_INS_OPTION") = "2";
    consts.attr("THOST_FTDC_INS_COMB") = "3";
    consts.attr("THOST_FTDC_TD_ALL") = "0";
    consts.attr("THOST_FTDC_TD_TRADE") = "1";
    consts.attr("THOST_FTDC_TD_UNTRADE") = "2";
    consts.attr("THOST_FTDC_PS_tradeable") = "1";
    consts.attr("THOST_FTDC_PS_untradeable") = "2";
    consts.attr("THOST_FTDC_SDS_Readable") = "1";
    consts.attr("THOST_FTDC_SDS_Reading") = "2";
    consts.attr("THOST_FTDC_SDS_Readend") = "3";
    consts.attr("THOST_FTDC_SDS_OptErr") = "e";
    consts.attr("THOST_FTDC_ACD_Add") = "1";
    consts.attr("THOST_FTDC_ACD_Del") = "2";
    consts.attr("THOST_FTDC_ACD_Upd") = "3";
    
}